@@ -99,6 +99,7 @@ Please check:
 
     def __set_to_result(self, parent_hex, current_hex, current_path_key):
         current_node = self.nodes[current_hex]
+        isa_type = current_node['isa']
         if isinstance(current_path_key, (list, tuple)):
             current_path = '/'.join([current_node[i] for i in current_path_key])
         elif isinstance(current_path_key, (basestring, unicode)):
@@ -110,9 +111,9 @@ Please check:
             raise KeyError('current_path_key must be list/tuple/string')
         cur_abs_path = '{}/{}'.format(self.__result[parent_hex]['path'], current_path)
         self.__result.update({
-            current_hex: {'path': cur_abs_path,
+            current_hex: {'path': '{}[{}]'.format(isa_type, cur_abs_path),
                           'new_key': md5_hex(cur_abs_path),
-                          'type': self.nodes[current_hex]['isa']
+                          'type': isa_type
             }
         })
 
@@ -173,6 +174,7 @@ Please check:
                     continue
                 # remove incorrect entry that somehow does not exist in project node tree
                 elif not all(self.__result.get(uuid) for uuid in key_list):
+                    self.vprint("Some node(s) are not in generated result, remove this line :",key_list)
                     removed_lines.append(new_line)
                     continue
                 else:
@@ -431,6 +433,7 @@ Please check:
             if self.nodes[current_hex]['isa'] == 'PBXReferenceProxy':
                 self.__unique_container_item_proxy(parent_hex, self.nodes[current_hex]['remoteRef'])
         else:
+            self.vprint("Group/FileReference/ReferenceProxy '", group_ref_hex, "' not found, it will be removed.")
             self.__result.setdefault('to_be_removed', []).append(group_ref_hex)
 
     def __unique_build_file(self, parent_hex, build_file_hex):
@@ -441,18 +444,21 @@ Please check:
         else:
             file_ref_hex = current_node.get('fileRef')
             if not file_ref_hex:
+                self.vprint("PBXFileReference '", file_ref_hex, "' not found, it will be removed.")
                 self.__result.setdefault('to_be_removed', []).append(build_file_hex)
             else:
                 if self.__result.get(file_ref_hex):
                     cur_path_key = self.__result[file_ref_hex]['path']
                     self.__set_to_result(parent_hex, build_file_hex, cur_path_key)
                 else:
+                    self.vprint("PBXFileReference '", file_ref_hex, "' not found inPBXBuildFile :", build_file_hex,'. To be removed.',sep='')
                     self.__result.setdefault('to_be_removed', []).extend((build_file_hex, file_ref_hex))
 
     def __unique_build_rules(self, parent_hex, build_rule_hex):
         '''PBXBuildRule'''
         current_node = self.nodes.get(build_rule_hex)
         if not current_node:
+            self.vprint("PBXBuildRule '", current_node, "' not found, it will be removed.")
             self.__result.setdefault('to_be_removed', []).append(build_rule_hex)
         else:
             file_type = current_node['fileType']
